@@ -1,6 +1,6 @@
 /*
  * iostat: report CPU and I/O statistics
- * (C) 1999-2007 by Sebastien Godard (sysstat <at> wanadoo.fr)
+ * (C) 1999-2007 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _IOSTAT_H
@@ -27,6 +27,7 @@
 #define I_F_HAS_NFS		0x08000
 #define I_D_DEVMAP_NAME		0x10000
 #define I_D_ISO			0x20000
+#define I_D_HUMAN_READ		0x40000
 
 #define DISPLAY_CPU(m)		(((m) & I_D_CPU) == I_D_CPU)
 #define DISPLAY_DISK(m)		(((m) & I_D_DISK) == I_D_DISK)
@@ -46,6 +47,8 @@
 #define HAS_NFS(m)		(((m) & I_F_HAS_NFS) == I_F_HAS_NFS)
 #define DISPLAY_DEVMAP_NAME(m)	(((m) & I_D_DEVMAP_NAME) == I_D_DEVMAP_NAME)
 #define DISPLAY_ISO(m)		(((m) & I_D_ISO) == I_D_ISO)
+#define DISPLAY_HUMAN_READ(m)	(((m) & I_D_HUMAN_READ) == I_D_HUMAN_READ)
+
 
 #define DT_DEVICE	0
 #define DT_PARTITION	1
@@ -54,14 +57,14 @@
 #define K_HDISK	"hdisk"
 
 struct comm_stats {
-   unsigned long long uptime;
-   unsigned long long uptime0;
-   unsigned long long cpu_iowait;
-   unsigned long long cpu_idle;
-   unsigned long long cpu_user;
-   unsigned long long cpu_nice;
-   unsigned long long cpu_system;
-   unsigned long long cpu_steal;
+	unsigned long long uptime;
+	unsigned long long uptime0;
+	unsigned long long cpu_iowait;
+	unsigned long long cpu_idle;
+	unsigned long long cpu_user;
+	unsigned long long cpu_nice;
+	unsigned long long cpu_system;
+	unsigned long long cpu_steal;
 };
 
 #define COMM_STATS_SIZE	(sizeof(struct comm_stats))
@@ -81,63 +84,65 @@ struct comm_stats {
  * structure is set to 0.
  */
 struct io_stats {
-   /* # of sectors read */
-   unsigned long long rd_sectors		__attribute__ ((aligned (8)));
-   /* # of sectors written */
-   unsigned long long wr_sectors		__attribute__ ((packed));
-   /* # of read operations issued to the device */
-   unsigned long rd_ios				__attribute__ ((packed));
-   /* # of read requests merged */
-   unsigned long rd_merges			__attribute__ ((packed));
-   /* Time of read requests in queue */
-   unsigned long rd_ticks			__attribute__ ((packed));
-   /* # of write operations issued to the device */
-   unsigned long wr_ios				__attribute__ ((packed));
-   /* # of write requests merged */
-   unsigned long wr_merges			__attribute__ ((packed));
-   /* Time of write requests in queue */
-   unsigned long wr_ticks			__attribute__ ((packed));
-   /* # of I/Os in progress */
-   unsigned long ios_pgr			__attribute__ ((packed));
-   /* # of ticks total (for this device) for I/O */
-   unsigned long tot_ticks			__attribute__ ((packed));
-   /* # of ticks requests spent in queue */
-   unsigned long rq_ticks			__attribute__ ((packed));
-   /* # of I/O done since last reboot */
-   unsigned long dk_drive			__attribute__ ((packed));
-   /* # of blocks read */
-   unsigned long dk_drive_rblk			__attribute__ ((packed));
-   /* # of blocks written */
-   unsigned long dk_drive_wblk			__attribute__ ((packed));
+	/* # of sectors read */
+	unsigned long long rd_sectors	__attribute__ ((aligned (8)));
+	/* # of sectors written */
+	unsigned long long wr_sectors	__attribute__ ((packed));
+	/* # of read operations issued to the device */
+	unsigned long rd_ios		__attribute__ ((packed));
+	/* # of read requests merged */
+	unsigned long rd_merges		__attribute__ ((packed));
+	/* Time of read requests in queue */
+	unsigned long rd_ticks		__attribute__ ((packed));
+	/* # of write operations issued to the device */
+	unsigned long wr_ios		__attribute__ ((packed));
+	/* # of write requests merged */
+	unsigned long wr_merges		__attribute__ ((packed));
+	/* Time of write requests in queue */
+	unsigned long wr_ticks		__attribute__ ((packed));
+	/* # of I/Os in progress */
+	unsigned long ios_pgr		__attribute__ ((packed));
+	/* # of ticks total (for this device) for I/O */
+	unsigned long tot_ticks		__attribute__ ((packed));
+	/* # of ticks requests spent in queue */
+	unsigned long rq_ticks		__attribute__ ((packed));
+	/* # of I/O done since last reboot */
+	unsigned long dk_drive		__attribute__ ((packed));
+	/* # of blocks read */
+	unsigned long dk_drive_rblk	__attribute__ ((packed));
+	/* # of blocks written */
+	unsigned long dk_drive_wblk	__attribute__ ((packed));
 };
 
 #define IO_STATS_SIZE	(sizeof(struct io_stats))
 
 struct io_nfs_stats {
-   unsigned long long rd_normal_bytes		__attribute__ ((aligned (8)));
-   unsigned long long wr_normal_bytes		__attribute__ ((packed));
-   unsigned long long rd_direct_bytes		__attribute__ ((packed));
-   unsigned long long wr_direct_bytes		__attribute__ ((packed));
-   unsigned long long rd_server_bytes		__attribute__ ((packed));
-   unsigned long long wr_server_bytes		__attribute__ ((packed));
+	unsigned long long rd_normal_bytes	__attribute__ ((aligned (8)));
+	unsigned long long wr_normal_bytes	__attribute__ ((packed));
+	unsigned long long rd_direct_bytes	__attribute__ ((packed));
+	unsigned long long wr_direct_bytes	__attribute__ ((packed));
+	unsigned long long rd_server_bytes	__attribute__ ((packed));
+	unsigned long long wr_server_bytes	__attribute__ ((packed));
+	unsigned long rpc_sends			__attribute__ ((packed));
+	unsigned long rpc_recvs			__attribute__ ((packed));
 };
 
 #define IO_NFS_STATS_SIZE	(sizeof(struct io_nfs_stats))
 
 struct io_hdr_stats {
-   unsigned int active				__attribute__ ((aligned (4)));
-   unsigned int used				__attribute__ ((packed));
-   char name[MAX_NAME_LEN];
+	unsigned int active		__attribute__ ((aligned (4)));
+	unsigned int used		__attribute__ ((packed));
+	char name[MAX_NAME_LEN];
 };
 
 #define IO_HDR_STATS_SIZE	(sizeof(struct io_hdr_stats))
 
 /* List of devices entered on the command line */
 struct io_dlist {
-   /* Indicate whether its partitions are to be displayed or not */
-   int disp_part				__attribute__ ((aligned (4)));
-   /* Device name */
-   char dev_name[MAX_NAME_LEN];
+	/* Indicate whether its partitions are to be displayed or not */
+	int disp_part			__attribute__ ((aligned (4)));
+	/* Device name */
+	char dev_name[MAX_NAME_LEN];
 };
 
 #define IO_DLIST_SIZE	(sizeof(struct io_dlist))
