@@ -14,8 +14,17 @@
 #define NOVAL      0		/* For placeholder zeros */
 #define DNOVAL     0.0		/* Wilma!  */
 
+
+/* Output formats (O_= Output)  */
+#define S_O_HDR_OPTION		1
+#define S_O_PPC_OPTION		2
+#define S_O_DB_OPTION		3
+#define S_O_XML_OPTION		4
+#define S_O_DBD_OPTION		5
+
+
 /* DTD version for XML output */
-#define XML_DTD_VERSION	"1.5"
+#define XML_DTD_VERSION	"1.6"
 
 static char *seps[] =  {"\t", ";"};
 
@@ -27,11 +36,11 @@ static char *seps[] =  {"\t", ";"};
 typedef enum e_tcons {iv, sv} tcons; /* Types of conses */
 
 typedef struct {
-   tcons t;			/* Type in {iv,sv} */
-   union {
-      unsigned long int i;
-      char *s;
-   } a, b;			/* Value pair, either ints or char *s */
+	tcons t;		/* Type in {iv,sv} */
+	union {
+		unsigned long int i;
+		char *s;
+	} a, b;			/* Value pair, either ints or char *s */
 } Cons;
 
 #endif  /* _SADF_H */
